##############################################################################
Oxford Instruments Intelligent Power Supply 120-10 for superconducting magnets
##############################################################################

.. autoclass:: pymeasure.instruments.oxfordinstruments.IPS120_10
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.oxfordinstruments.ips120_10.MagnetError
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.oxfordinstruments.ips120_10.SwitchHeaterError
    :members:
    :show-inheritance:
